@@ -1,8 +1,32 @@
 `multistageselection` <-
-function(k,corr,alphaofx,sumdimofxandy)
+function(k,corr,alphaofx,sumdimofxandy,alg= GenzBretz())
 {
+
+
  
-dim=sumdimofxandy
+dim=sumdimofxandy  
+# in one stage selection case dim = 2
+
+for (i in 1:dim)
+{
+   if (is.infinite(k[i])==TRUE)
+   {
+     k[i]=-100
+   }
+}
+
+
+if (dim<2)
+{
+stop("dimension of k must bigger than 1, otherwise this is not one-stage selection")
+
+}else if(dim==2)
+{
+gainresult=corr[1,2]*dnorm(k[2])/alphaofx
+
+
+}else
+{
 
 A=array(0,c(dim,dim))
 
@@ -49,7 +73,7 @@ j3q<-function (q,A,part.corr,dim)
 
 
     output=pmvnorm(lower = lower, upper = rep(Inf,c(dim-1)), mean = rep(0, length(lower)), 
-    corr = corr, sigma = NULL, algorithm = GenzBretz()) 
+    corr = corr, sigma = NULL, algorithm =  alg) 
     output
  }
 
@@ -59,16 +83,18 @@ calculatx1<-function(A,part.corr,dim,corr,k,alpha3)
    i=1
    for (i in 1 : dim)
  {
-   output= output+ corr[1,i]*dnorm(k[i])*j3q(i,A,part.corr,dim)
+   output= output+ corr[1,i]*dnorm(k[i])*j3q(i,A,part.corr,dim)/alpha3
  }
    
-   output=output/alpha3
+
 
   output
 }
   
 
-calculatx1(A=A,part.corr=part.corr,dim=dim,corr=corr,k=k,alpha3=alphaofx)
+gainresult<-calculatx1(A=A,part.corr=part.corr,dim=dim,corr=corr,k=k,alpha3=alphaofx)
 
 }
+gainresult
+}
 
